Documentation
¶
Overview ¶
Package v1 contains API Schema definitions for the mongodb v1 API group +k8s:deepcopy-gen=package,register +groupName=mongodb.com
Package v1 contains API Schema definitions for the mongodb v1 API group +k8s:deepcopy-gen=package,register +groupName=mongodb.com
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // SchemeGroupVersion is group version used to register these objects SchemeGroupVersion = schema.GroupVersion{Group: "mongodb.com", Version: "v1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: SchemeGroupVersion} )
Functions ¶
This section is empty.
Types ¶
type MongoDB ¶
type MongoDB struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec MongoDBSpec `json:"spec,omitempty"`
Status MongoDBStatus `json:"status,omitempty"`
}
MongoDB is the Schema for the mongodbs API +kubebuilder:subresource:status +kubebuilder:resource:path=mongodbs,scope=Namespaced
func (MongoDB) BuildStatefulSet ¶
func (m MongoDB) BuildStatefulSet() appsv1.StatefulSet
TODO: build the correct statefulset - this is a dummy implementation BuildStatefulSet constructs an instance of appsv1.StatefulSet which should be created during reconciliation
func (*MongoDB) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MongoDB.
func (*MongoDB) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MongoDB) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*MongoDB) ServiceName ¶
ServiceName returns the name of the Service that should be created for this resource
type MongoDBList ¶
type MongoDBList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []MongoDB `json:"items"`
}
MongoDBList contains a list of MongoDB
func (*MongoDBList) DeepCopy ¶
func (in *MongoDBList) DeepCopy() *MongoDBList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MongoDBList.
func (*MongoDBList) DeepCopyInto ¶
func (in *MongoDBList) DeepCopyInto(out *MongoDBList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MongoDBList) DeepCopyObject ¶
func (in *MongoDBList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type MongoDBSpec ¶
type MongoDBSpec struct {
// Members is the number of members in the replica set
// +optional
Members int32 `json:"members"`
// Kind defines which kind of MongoDB deployment the resource should create
Kind Kind `json:"kind"`
// Version defines which version of MongoDB will be used
Version string `json:"version"`
}
MongoDBSpec defines the desired state of MongoDB
func (*MongoDBSpec) DeepCopy ¶
func (in *MongoDBSpec) DeepCopy() *MongoDBSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MongoDBSpec.
func (*MongoDBSpec) DeepCopyInto ¶
func (in *MongoDBSpec) DeepCopyInto(out *MongoDBSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MongoDBStatus ¶
type MongoDBStatus struct {
}
MongoDBStatus defines the observed state of MongoDB
func (*MongoDBStatus) DeepCopy ¶
func (in *MongoDBStatus) DeepCopy() *MongoDBStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MongoDBStatus.
func (*MongoDBStatus) DeepCopyInto ¶
func (in *MongoDBStatus) DeepCopyInto(out *MongoDBStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.